@@ -2,6 +2,11 @@
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import * 
 
+import datetime
+
+import inforion.ionapi.model.inforlogin as inforlogin_info
+import inforion.ionapi.basic as inforlogin
+
 class TimeoutHTTPAdapter(HTTPAdapter):
     def __init__(self, *args, **kwargs):
         self.timeout = DEFAULT_TIMEOUT
@@ -38,7 +43,7 @@ def requests_retry_session(
 
     
 
-def sendresults(url,headers, data,timeout=65):
+def sendresults(url,headers, data,timeout=65,stream=False):
     
     retry_strategy = Retry(
         total=5,
@@ -51,13 +56,26 @@ def sendresults(url,headers, data,timeout=65):
     http.mount("https://", adapter)
     http.mount("http://", adapter)
 
+   
+
     
+
+    
+    if datetime.datetime.now().time() > inforlogin_info._GLOBAL_session_expire:
+        
+        headers = inforlogin.reconnect(url,headers)
+        print (" Reconnect and Next Reconnect will be " + str(inforlogin_info._GLOBAL_session_expire))
+        #print (headers)
+        
+        
+
+
     
     
     try:
                     
         #response = requests.request("POST", url, headers=headers, data=json.dumps(data),timeout=15)
-        response = http.request("POST", url, headers=headers, data=json.dumps(data),timeout=timeout)
+        response = http.request("POST", url, headers=headers, data=json.dumps(data),timeout=timeout,stream=stream)
                
         if response.status_code == 200:
             try:
@@ -81,7 +99,7 @@ def sendresults(url,headers, data,timeout=65):
     
     return r
 
-def saveresults(r,df,program,index,chunk,elements=1):
+def saveresults(r,df,program,index,chunk,MaxChunk=150,elements=1):
 
     message = ''
     max_elements = elements
