@@ -1,5 +1,6 @@
 
 import pandas as pd
+import numpy as np
 import requests
 import inforion
 import json
@@ -28,7 +29,7 @@ import inforion.helper.filehandling as filehandling
 #from inforion.ionapi.model import 
 
 DEFAULT_TIMEOUT = 50 # seconds
-MaxChunk = 150
+MaxChunk = 100
 
 
 
@@ -92,7 +93,7 @@ def execute(url,headers,program,methode,dataframe,outputfile=None,start=0,end=No
                 data['transactions'] = a
 
                 r = controller.sendresults(url,headers,data)
-                df,data,chunk = controller.saveresults(r,df,program,index,chunk,methode_count)
+                df,data,chunk = controller.saveresults(r,df,program,index,chunk,MaxChunk,methode_count)
                 data1 = {}
                 a = []
                  
@@ -105,12 +106,13 @@ def execute(url,headers,program,methode,dataframe,outputfile=None,start=0,end=No
         
         r = controller.sendresults(url,headers,data)
         index = index + 1 
-        df,data,chunk = controller.saveresults(r,df,methode,index,chunk,methode_count)
+        df,data,chunk = controller.saveresults(r,df,methode,index,chunk,MaxChunk,methode_count)
 
 
+    df = df.replace(np.nan, '', regex=True)
+    df = df.astype(str)
+
     if outputfile is not None:
-        
-
         print ('Save to file: ' + outputfile)
         filehandling.savetodisk(outputfile,df)
     
@@ -122,12 +124,13 @@ def executeSnd(url,headers,program,methode,dataframe,outputfile=None,start=0,end
     df = dataframe
 
 
-    tdata = {'program': program,
+    data = {'program': program,
             'cono':    409 }
         
-    #/ChgOrderInfo
-    #/ChgFinancial
-    #/ChgBasicData
+
+
+    methode = methode.split(",")
+    methode_count = len(methode)
     
     mylist = []
     data1 = {}
@@ -141,7 +144,7 @@ def executeSnd(url,headers,program,methode,dataframe,outputfile=None,start=0,end
         counter = 0
         df = df[start:end].copy(deep=False)
         df = df.reset_index(drop=True)
-        #print (df.head(10))
+        
         
     #else:
     total_rows = df.shape[0]
@@ -162,26 +165,31 @@ def executeSnd(url,headers,program,methode,dataframe,outputfile=None,start=0,end
             row = row.to_json()
             row = json.loads(row)
 
+            for i in methode:
+                data1['transaction'] = i
+                data1['record'] = row
+                a.append(data1.copy())
             
-            
-            data1['transaction'] = methode
-            data1['record'] = row
-            
+           
 
-            a.append(data1.copy())
-
-            
-        
-               
+                
         
         data['transactions'] = a
-        r = sendresults(url,headers,data)
+    
         index = index + 1 
-        df,data,chunk = saveresults(r,df,methode,index,chunk)
+        
+    
+    print (data)
 
+    r = controller.sendresults(url,headers,data)
+
+
+    df,data,chunk = controller.saveresults(r,df,methode,index,chunk)
+
+    df = df.replace(np.nan, '', regex=True)
+    df = df.astype(str)
 
     if outputfile is not None:
-        
         print ('Save to file: ' + outputfile)
         filehandling.savetodisk(outputfile,df)
     
@@ -189,12 +197,15 @@ def executeSnd(url,headers,program,methode,dataframe,outputfile=None,start=0,end
 
 def executeAsyncSnd(url,headers,program,methode,dataframe,outputfile=None,start=0,end=None):
 
+    print ("Still in Beta")
+
     df = dataframe
         
     data = {'program': program,
             'cono':    409 }
         
-
+    methode = methode.split(",")
+    methode_count = len(methode)
     
     mylist = []
     data1 = {}
@@ -229,15 +240,10 @@ def executeAsyncSnd(url,headers,program,methode,dataframe,outputfile=None,start=
             row = row.to_json()
             row = json.loads(row)
 
-            if type(methode) == str:
-                data1['transaction'] = methode
+            for i in methode:
+                data1['transaction'] = i
                 data1['record'] = row
                 a.append(data1.copy())
-            elif type(methode) == list:
-                for i in range(len(methode)):
-                    data1['transaction'] = methode(i)
-                    data1['record'] = row
-                    a.append(data1.copy())
 
             
 
@@ -249,17 +255,24 @@ def executeAsyncSnd(url,headers,program,methode,dataframe,outputfile=None,start=
         
         data['transactions'] = a
 
+
         print (data)
 
-        r = sendresults(url,headers,data)
+        r = controller.sendresults(url,headers,data,stream=True)
         index = index + 1 
         #df,data,chunk = saveresults(r,df,methode,index,chunk)
 
-        print (r)
+    print (r)
 
+    '''
+
+    df = df.replace(np.nan, '', regex=True)
+    df = df.astype(str)
     
     if outputfile is not None:
         print ('Save to file: ' + outputfile)
         filehandling.savetodisk(outputfile,df)
     
-    return df
\ No newline at end of file
+    return df
+
+    '''
\ No newline at end of file
